===========
Django Belt
===========

Simple package with some utilities for Django.

Quick start
-----------

**1** Install using pip::

    pip install django-belt

**2** Add "belt" to your INSTALLED_APPS settings like this::

    INSTALLED_APPS += ('belt',)

